df_http library

Classes

DfApiClient
Centralized HTTP API client used for all network calls.
DfHttpClientConfig
Configuration object for HTTP API calls used with df_http.
Failure<S, E extends Exception>
Result<S, E extends Exception>
Base Result class S represents the type of the success value E should be Exception or a subclass of it
Success<S, E extends Exception>